#/usr/bin/python3

import libtmux
import time
import subprocess
import os
import os.path

SOCKET_NAME='needrestart-tmux'
MOCKUNAME_SO = f'{os.environ.get("AUTOPKGTEST_TMP", "/tmp")}/mockuname.so'

def get_session(server: libtmux.Server, name) -> libtmux.Session:
    return server.new_session(session_name=name, attach=False, window_command='bash -l', x=132, y=80)

def test_kernel_version_mismatch(server: libtmux.Server):
    session = get_session(server, 'needrestart-kernel-mismatch')
    try:
        pane = session.attached_pane
        assert pane
        pane.send_keys(f"LANG=C LD_PRELOAD={MOCKUNAME_SO} DEBIAN_FRONTEND=dialog apt reinstall hello && echo '******DONE******'")
        time.sleep(15) # This ought to be enough for that operation
        lines = pane.capture_pane()
        assert not isinstance(lines, str)
        print()
        print("TMUX SCREEN:")
        print("\n".join(lines))
        print()
        assert '******DONE******' in '\n'.join(lines) # That means we're not stuck on a debconf prompt
        assert os.path.exists('/run/reboot-required')
    finally:
        session.kill_session()


if __name__ == '__main__':
    subprocess.run(['gcc', '-shared', '-fPIC', '-ldl', 'debian/tests/mockuname.c', '-o', MOCKUNAME_SO], check=True)
    server = libtmux.Server(socket_name=SOCKET_NAME)
    try:
        test_kernel_version_mismatch(server)
    finally:
        server.kill_server()

